# MUDE week 2.2 (Python, Bash, HPC)

This workshop shows the basics of high-performance computing.

It consists of three parts [estimated time in the brackets]:

1. Python - vectorization and numba (compulsory) [~1.5 hours, 1 assignment]
2. Linux shell basics (optional) [~1.5 hours, 3 assignments]
3. Running jobs on cluster using SLURM (optional) [~1.5 hours]

## Introduction

As you might notice, even for a simple 2D problem with a Poisson equation, the solution takes some time. So writing efficient code is important.

In the first part, we are going to compare different implementations for the same task using loops, vectorization, and numba. We also will parallelize the code to use all the cores of our computer.

In the second part, we will learn how to use Linux shell, because this is necessary for the third step (most of the supercomputers have Linux).

The third part of the workshop shows how to use job queues to run tasks on the DelftBlue supercomputer. This makes sense for real 3D problems with complex physics and a large number of cells when the computation takes hours and days. Also, a huge set of tasks generated by uncertainty quantification can be run on the computing nodes of a cluster.


## Input data for the tasks
* Part2_shell\Week_2_2


## Software

You can use JupiterHub, the online framework with Jupiter Notebook and Bash terminal for the first and second parts.
Link: https://jupyter.lisa.surfsara.nl/jhltud001/hub/spawn-pending

There are few alternate ways to work with Python (Anaconda or WinPython) and Bash (MobaXterm, git bash, WSL) as well, you will find some details below.

For the third part we will use MobaXterm. 

### Python

Python 3.7 or higher is needed. We will use the next Python modules: numpy, numba. 
They can be installed with the command 

```bash
pip install -r requirements.txt
```

from the Python directory of this repo. We also will use Jupiter Notebook. 

If you use Windows, you can download and install 
<a href=https://github.com/winpython/winpython/releases/download/5.0.20221030final/Winpython64-3.11.0.1.exe>WinPython</a>, 
it contains Jupiter Notebook. Of course, Anaconda will also work for it.


### Bash (for Linux users)

If you work on Linux, you only need `open-ssh-client` installed. `ssh` command used to connect to remote Linux host (supercomputer) and run commands there.


### Bash (for Windows users)

**MobaXterm**

To run Linux commands on the remote machine we will use <a href=https://mobaxterm.mobatek.net/>MobaXterm</a> software. It is a Windows SSH-client application. You can download it 
<a href=https://mobaxterm.mobatek.net/download-home-edition.html>here</a>.
You can run the terminal in MobaXterm on your local machine, and run Linux commands too.

**WSL**
Windows 10 users might install Ubuntu based on WSL (Windows subsystem for Linux), this allows running Linux commands on their local machine. 

**WSL installation and using instructions**

* Run PowerShell from Administrator 
* Run `wsl --install`
<img width=55% src="images/powershell_wsl_install.png"></img>
* Reboot Windows
* Open Microsoft Store
* Type "Ubuntu" in the search line
* Select "Ubuntu 22.04 LTS"
* Click "Get" to install
* Click "Run" after the installation 
* The window with a Linux command line should appear:
<img width=55% src="images/wsl_ubuntu.png"></img>
* It is a bare Linux, so you need to install packages (Python, etc) 
* You might want to install a file manager, for example Midnight Commander. Use following commands for this:
```bash
sudo apt update
sudo apt install mc
```
Then type `mc` to run Midnight Commander.
<img width=55% src="images/wsl_ubuntu_mc.png"></img>
* Use "Start" button to run Ubuntu later:
<img width=25% src="images/wsl_ubuntu_start.png"></img>

**git bash**

Git Bash is a part of Git software. It allows to execute Linux commands on Windows (uses MINGW).
